from ..math.transform import Transform

class Key:
    """Class to represent a keyframe in a joint animation.

    Attributes:
    ----------
    time : float
        The time of the keyframe, normalized between 0 and 1.
    transform : Transform
        The transform of the joint at the keyframe.
    control_points : list of ControlPoint
        The control points to direct interpolation between the keyframe and the next keyframe.
    """

    def __init__(self, time, transform = Transform(), control_points = []):
        """**Default constructor for the Key class.**

        Raises:
        ----------
        ValueError
            If the time is not between 0 and 1.

        Parameters:
        ----------
        time : float
            The time of the keyframe, between 0 and 1.
        transform : Transform, optional
            The transform of the joint at the keyframe, by default identity matrix.
        control_points : list of ControlPoint, optional
            The control points to direct interpolation between the keyframe and the next keyframe, by default empty list.
        """
        if time < 0 or time > 1:
            raise ValueError("Key time must be between 0 and 1.")
        self.time = time
        self.transform = transform
        self.control_points = control_points